@@ -1,5 +1,5 @@
 from petisco import RabbitMqConnector
-from petisco.event.consumer.infrastructure.rabbitmq_event_comsumer import (
+from petisco.event.consumer.infrastructure.rabbitmq_event_consumer import (
     RabbitMqEventConsumer,
 )
 from tests.modules.event.mothers.defaults import (
@@ -22,6 +22,17 @@ class RabbitMqEventConsumerMother:
             DEFAULT_VERBOSE,
         )
 
+    @staticmethod
+    def with_service(service: str, connector: RabbitMqConnector = None):
+        connector = RabbitMqConnector() if not connector else connector
+        return RabbitMqEventConsumer(
+            connector,
+            DEFAULT_ORGANIZATION,
+            service,
+            DEFAULT_MAX_RETRIES,
+            DEFAULT_VERBOSE,
+        )
+
     @staticmethod
     def with_max_retries(max_retries: int, connector: RabbitMqConnector = None):
         connector = RabbitMqConnector() if not connector else connector
